..
    This file is part of hepcrawl.
    Copyright (C) 2016, 2017, 2018 CERN.

    hepcrawl is a free software; you can redistribute it and/or modify it
    under the terms of the Revised BSD License; see LICENSE file for
    more details.

.. currentmodule:: hepcrawl


Spiders
-------

.. contents::
    :local:
    :backlinks: none

APS
~~~

.. automodule:: hepcrawl.spiders.aps_spider
   :members:


arXiv.org
~~~~~~~~~

.. automodule:: hepcrawl.spiders.arxiv_spider
   :members:

CDS
~~~

.. automodule:: hepcrawl.spiders.cds_spider
   :members:

Desy
~~~~

.. automodule:: hepcrawl.spiders.desy_spider
   :members:

EDP
~~~

.. automodule:: hepcrawl.spiders.edp_spider
   :members:


Elsevier
~~~~~~~~

.. automodule:: hepcrawl.spiders.elsevier_spider
   :members:


Hindawi
~~~~~~~

.. automodule:: hepcrawl.spiders.hindawi_spider
   :members:

IOP
~~~

.. automodule:: hepcrawl.spiders.iop_spider
   :members:

Proceedings of Science
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: hepcrawl.spiders.pos_spider
   :members:

World Scientific
~~~~~~~~~~~~~~~~

.. automodule:: hepcrawl.spiders.wsp_spider
   :members:

